===========
 dipy core
===========

.. automodule:: dipy.core
    :members:

.. currentmodule:: dipy.core

.. autosummary::
    :toctree:

    geometry
    gradients
    graph
    profile
    rng
    sphere
    sphere_stats
    subdivide_octahedron
    sphere_stats
